km3modules.topology.TriggeredDUs
================================

.. currentmodule:: km3modules.topology

.. autoclass:: TriggeredDUs

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~TriggeredDUs.__init__
      ~TriggeredDUs.add
      ~TriggeredDUs.configure
      ~TriggeredDUs.expose
      ~TriggeredDUs.finish
      ~TriggeredDUs.get
      ~TriggeredDUs.pre_finish
      ~TriggeredDUs.process
      ~TriggeredDUs.require
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~TriggeredDUs.name
   
   